@@ -5,20 +5,19 @@ use 5.010;
 
 # ABSTRACT: use categories when tracking time with App::TimeTracker
 
-our $VERSION = "1.001";
+our $VERSION = "1.002";
 
 use Moose::Util::TypeConstraints;
 use Moose::Role;
 
-after '_load_attribs_start' => sub {
+sub munge_start_attribs {
     my ( $class, $meta, $config ) = @_;
-
     my $cfg = $config->{category};
     return unless $cfg && $cfg->{categories};
 
-    subtype 'ATT::Category'
-        => as enum($cfg->{categories})
-        => message {"$_ is not a valid category (as defined in the current config)"};
+    subtype 'ATT::Category' => as enum( $cfg->{categories} ) => message {
+        "$_ is not a valid category (as defined in the current config)"
+    };
 
     $meta->add_attribute(
         'category' => {
@@ -26,57 +25,65 @@ after '_load_attribs_start' => sub {
             is            => 'ro',
             required      => $cfg->{required},
             documentation => 'Category',
-        } );
-};
+        }
+    );
+}
+after '_load_attribs_start'    => \&munge_start_attribs;
+after '_load_attribs_append'   => \&munge_start_attribs;
+after '_load_attribs_continue' => \&munge_start_attribs;
 
 before [ 'cmd_start', 'cmd_continue', 'cmd_append' ] => sub {
     my $self = shift;
 
-    $self->add_tag($self->category);
+    if ( $self->category ) {
+        $self->add_tag( $self->category );
+    }
 };
 
 sub cmd_statistic {
     my $self = shift;
 
-    my @files = $self->find_task_files( {
-            from     => $self->from,
+    my @files = $self->find_task_files(
+        {   from     => $self->from,
             to       => $self->to,
             projects => $self->fprojects,
             tags     => $self->ftags,
             parent   => $self->fparent,
-        } );
+        }
+    );
     my $cats = $self->config->{category}{categories};
 
-    my $total  = 0;
+    my $total = 0;
     my %stats;
 
     foreach my $file (@files) {
-        my $task    = App::TimeTracker::Data::Task->load( $file->stringify );
-        my $time    = $task->seconds // $task->_build_seconds;
+        my $task = App::TimeTracker::Data::Task->load( $file->stringify );
+        my $time = $task->seconds // $task->_build_seconds;
         $total += $time;
-        my %tags = map { $_=>1 } @{$task->tags};
+        my %tags = map { $_ => 1 } @{ $task->tags };
 
         my $got_cat = 0;
         foreach my $cat (@$cats) {
-            if ($tags{$cat}) {
+            if ( $tags{$cat} ) {
                 $stats{$cat}{abs} += $time;
-                $got_cat=1;
+                $got_cat = 1;
                 last;
             }
         }
-        $stats{_no_cat}{abs}+=$time unless $got_cat;
+        $stats{_no_cat}{abs} += $time unless $got_cat;
     }
 
-    while (my ($cat, $data) = each %stats) {
-        $data->{percent} = sprintf("%.1f", $data->{abs} / $total * 100 );
-        $data->{nice} =  $self->beautify_seconds($data->{abs});
+    while ( my ( $cat, $data ) = each %stats ) {
+        $data->{percent} = sprintf( "%.1f", $data->{abs} / $total * 100 );
+        $data->{nice} = $self->beautify_seconds( $data->{abs} );
     }
 
     $self->_say_current_report_interval;
-    printf("%39s\n", $self->beautify_seconds($total));
-    foreach my $cat (sort keys %stats) {
+    printf( "%39s\n", $self->beautify_seconds($total) );
+    foreach my $cat ( sort keys %stats ) {
         my $data = $stats{$cat};
-        printf("%6s%%  %- 20s% 10s\n",$data->{percent},$cat, $data->{nice});
+        printf( "%6s%%  %- 20s% 10s\n",
+            $data->{percent}, $cat, $data->{nice} );
     }
 }
 
@@ -100,7 +107,7 @@ App::TimeTracker::Command::Category - use categories when tracking time with App
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 DESCRIPTION
 
@@ -141,8 +148,7 @@ Print stats on time worked per category
       15.7%  support               01:12:06
 
 You can use the same options as in C<report> to define which tasks you
-want stats on (C<--from, --until, --this, --last, --ftag, --fproject,
-..)
+want stats on (C<--from, --until, --this, --last, --ftag, --fproject, ..>)
 
 =head1 CHANGES TO OTHER COMMANDS
 
